@@ -1,19 +1,25 @@
-require 'rails/railtie'
-
 require 'active_support'
 
 require 'rabl-rails/version'
 require 'rabl-rails/helpers'
+require 'rabl-rails/exceptions'
 require 'rabl-rails/template'
 require 'rabl-rails/nodes'
 require 'rabl-rails/compiler'
 
 require 'rabl-rails/visitors'
-require 'rabl-rails/renderer'
+require 'rabl-rails/renderers/hash'
+require 'rabl-rails/renderers/json'
+require 'rabl-rails/renderers/xml'
+require 'rabl-rails/renderers/plist'
 require 'rabl-rails/library'
 
 require 'rabl-rails/handler'
-require 'rabl-rails/railtie'
+
+if defined?(Rails)
+  require 'rails/railtie'
+  require 'rabl-rails/railtie'
+end
 
 require 'rabl-rails/configuration'
 
@@ -25,8 +31,6 @@ rescue LoadError
 end
 
 module RablRails
-  extend Renderer
-
   class << self
     def configure
       yield configuration
