@@ -1,6 +1,5 @@
 require 'singleton'
 require 'monitor'
-require 'thread_safe'
 
 module RablRails
   class Library
@@ -16,17 +15,17 @@ module RablRails
     }.freeze
 
     def initialize
-      @cached_templates = ThreadSafe::Cache.new
-      @mutex = Monitor.new
+      @cached_templates = {}
+      @monitor = Monitor.new
     end
 
     def reset_cache!
-      @cached_templates = ThreadSafe::Cache.new
+      @cached_templates = {}
     end
 
     def get_rendered_template(source, view, locals = nil)
       compiled_template = compile_template_from_source(source, view)
-      format = view.lookup_context.rendered_format || :json
+      format = view.lookup_context.formats.first || :json
       raise UnknownFormat, "#{format} is not supported in rabl-rails" unless RENDERER_MAP.key?(format)
       RENDERER_MAP[format].render(compiled_template, view, locals)
     end
@@ -52,7 +51,7 @@ module RablRails
     private
 
     def synchronized_compile(path, source, view)
-      @cached_templates[path] || @mutex.synchronize do
+      @cached_templates[path] || @monitor.synchronize do
         # Any thread holding this lock will be compiling the template needed
         # by the threads waiting. So re-check the template presence to avoid
         # re-compilation
@@ -68,7 +67,9 @@ module RablRails
     end
 
     def fetch_source(path, view)
-      view.lookup_context.find_template(path, [], false).source
+      t = view.lookup_context.find_template(path, [], false)
+      t = t.refresh(view) unless t.source
+      t.source
     end
   end
-end
\ No newline at end of file
+end
