@@ -1,17 +1,20 @@
-require 'forwardable'
-
 module RablRails
   module Nodes
     class Attribute
-      include Node
-      extend Forwardable
-
-      def_delegators :@hash, :[]=, :each
-      attr_reader :hash
+      attr_reader   :hash
+      attr_accessor :condition
 
       def initialize(hash = {})
         @hash = hash
       end
+
+      def []=(key, value)
+        @hash[key] = value
+      end
+
+      def each(&block)
+        @hash.each(&block)
+      end
     end
   end
-end
\ No newline at end of file
+end
