@@ -1,7 +1,11 @@
 module Visitors
   class Visitor
     def visit(node)
-      dispatch node
+      dispatch(node)
+    end
+
+    def visit_Array a
+      a.each { |n| dispatch(n) }
     end
 
     private
@@ -14,4 +18,4 @@ module Visitors
       send DISPATCH[node.class], node
     end
   end
-end
\ No newline at end of file
+end
