@@ -7,6 +7,8 @@ require 'minitest/autorun'
 
 require 'rabl-rails'
 require 'plist'
+require 'action_dispatch/http/mime_type'
+require 'action_view'
 
 if RUBY_ENGINE == 'jruby'
   require 'nokogiri'
@@ -14,11 +16,7 @@ elsif RUBY_ENGINE == 'ruby'
   require 'libxml'
 end
 
-MINITEST_TEST_CLASS = if defined?(Minitest::Test)
-  Minitest::Test
-else
-  Minitest::Unit::TestCase
-end
+ActionView::Template.register_template_handler :rabl, RablRails::Handlers::Rabl
 
 module Configurable
   def with_configuration(key, value)
@@ -30,7 +28,7 @@ module Configurable
     RablRails.configuration.send(accessor, old_value)
   end
 end
-MINITEST_TEST_CLASS.send(:include, Configurable)
+Minitest::Test.send(:include, Configurable)
 
 module Rails
   def self.cache
@@ -51,8 +49,8 @@ class Context
       @format = format
     end
 
-    def rendered_format
-      @format.to_sym
+    def formats
+      [@format]
     end
   end
 
@@ -84,4 +82,4 @@ class User
     @id = id
     @name = name
   end
-end
\ No newline at end of file
+end
