@@ -1,6 +1,6 @@
 require 'helper'
 
-class TestConfiguration < MINITEST_TEST_CLASS
+class TestConfiguration < Minitest::Test
   describe 'Configuration' do
     it 'has a zero score by default' do
       config = RablRails::Configuration.new
@@ -28,4 +28,4 @@ class TestConfiguration < MINITEST_TEST_CLASS
       assert_equal 3, config.result_flags
     end
   end
-end
\ No newline at end of file
+end
